@@ -5,7 +5,7 @@ use warnings;
 use 5.0100;
 
 # ABSTRACT: OpenSMILES format reader and writer
-our $VERSION = '0.4.1'; # VERSION
+our $VERSION = '0.4.2'; # VERSION
 
 require Exporter;
 our @ISA = qw( Exporter );
@@ -19,6 +19,26 @@ sub is_aromatic($)
     return $atom->{symbol} ne ucfirst $atom->{symbol};
 }
 
+sub _validate($)
+{
+    my( $moiety ) = @_;
+
+    for my $atom (sort { $a->{number} <=> $b->{number} } $moiety->vertices) {
+        # TODO: TH and AL chiral centers also have to be checked
+        next if !$atom->{chirality} || $atom->{chirality} !~ /^@@?$/;
+        next if $moiety->degree($atom) >= 4;
+        # FIXME: tetrahedral allenes are false-positives
+        warn sprintf 'chiral center %s(%d) has %d bonds while ' .
+                     'at least 4 is required' . "\n",
+                     $atom->{symbol},
+                     $atom->{number},
+                     $moiety->degree($atom);
+    }
+
+    # TODO: cis/trans bond not next to a double bond
+    # TODO: SP, TB, OH chiral centers
+}
+
 1;
 
 __END__
@@ -43,9 +63,9 @@ Chemistry::OpenSMILES - OpenSMILES format reader and writer
         print scalar $moiety->edges;
     }
 
-    use Chemistry::OpenSMILES::Writer;
+    use Chemistry::OpenSMILES::Writer qw(write_SMILES);
 
-    print Chemistry::OpenSMILES::Writer::write( \@moieties );
+    print write_SMILES( \@moieties );
 
 =head1 DESCRIPTION
 
