@@ -7,12 +7,24 @@ use Chemistry::OpenSMILES qw(is_aromatic);
 use Graph::Traversal::DFS;
 
 # ABSTRACT: OpenSMILES format writer
-our $VERSION = '0.4.1'; # VERSION
+our $VERSION = '0.4.2'; # VERSION
 
-sub write
+require Exporter;
+our @ISA = qw( Exporter );
+our @EXPORT_OK = qw(
+    write_SMILES
+);
+
+sub write_SMILES
 {
     my( $what, $order_sub ) = @_;
 
+    if( ref $what eq 'HASH' ) {
+        # subroutine will also accept and properly represent a single
+        # atom:
+        return _pre_vertex( $what );
+    }
+
     my @moieties = ref $what eq 'ARRAY' ? @$what : ( $what );
     my @components;
 
@@ -27,15 +39,23 @@ sub write
         my $rings = {};
 
         my $operations = {
-            tree_edge     => sub { push @symbols, _tree_edge( @_ ) },
-            non_tree_edge => sub { my @sorted = sort { $a <=> $b }
-                                                     map { $vertex_symbols{$_} }
-                                                         @_[0..1];
-                                   $rings->{$sorted[0]}{$sorted[1]} =
-                                        _depict_bond( @_[0..1], $graph ); },
+            tree_edge     => sub { if( $vertex_symbols{$_[1]} ) {
+                                       @_ = ( $_[1], $_[0], $_[2] );
+                                   }
+                                   push @symbols, _tree_edge( @_ ) },
+            non_tree_edge => sub { my @sorted = sort { $vertex_symbols{$a} <=>
+                                                       $vertex_symbols{$b} }
+                                                     @_[0..1];
+                                   $rings->{$vertex_symbols{$sorted[0]}}
+                                           {$vertex_symbols{$sorted[1]}} =
+                                        _depict_bond( @sorted, $graph ); },
 
-            pre  => sub { push @symbols, _pre_vertex( @_ );
-                          $vertex_symbols{$_[0]} = $#symbols },
+            pre  => sub { my( $vertex, $graph ) = @_;
+                          push @symbols,
+                         _pre_vertex( { map { $_ => $vertex->{$_} }
+                                        grep { $_ ne 'chirality' }
+                                        keys %$vertex }, $graph );
+                          $vertex_symbols{$vertex} = $#symbols },
             post => sub { push @symbols, ')' },
         };
 
@@ -85,6 +105,12 @@ sub write
     return join '.', @components;
 }
 
+# DEPRECATED
+sub write
+{
+    &write_SMILES;
+}
+
 sub _tree_edge
 {
     my( $u, $v, $self ) = @_;
@@ -94,7 +120,7 @@ sub _tree_edge
 
 sub _pre_vertex
 {
-    my( $vertex, $self ) = @_;
+    my( $vertex ) = @_;
 
     my $atom = $vertex->{symbol};
     my $is_simple = $atom =~ /^[bcnosp]$/i ||
@@ -133,10 +159,14 @@ sub _depict_bond
 {
     my( $u, $v, $graph ) = @_;
 
-    # CAVEAT: '/' and '\' bonds are problematic
-    return $graph->has_edge_attribute( $u, $v, 'bond' )
-         ? $graph->get_edge_attribute( $u, $v, 'bond' )
-         : is_aromatic $u && is_aromatic $v ? '-' : '';
+    if( !$graph->has_edge_attribute( $u, $v, 'bond' ) ) {
+        return is_aromatic $u && is_aromatic $v ? '-' : '';
+    }
+
+    my $bond = $graph->get_edge_attribute( $u, $v, 'bond' );
+    return $bond if $bond ne '/' && $bond ne '\\';
+    return $bond if $u->{number} < $v->{number};
+    return $bond eq '/' ? '\\' : '/';
 }
 
 sub _order
